@@ -3,17 +3,25 @@ from os.path import dirname, join
 import pandas as pd
 
 
-def load_daily():
-    """4 series of sample daily data from late 2019."""
+def load_daily(long: bool = True):
+    """2020 Covid, Air Pollution, and Economic Data.
+
+    Sources: Covid Tracking Project, EPA, and FRED
+
+    Args:
+        long (bool): if True, return data in long format. Otherwise return wide
+    """
     module_path = dirname(__file__)
-    data_file_name = join(module_path, 'data', 'toy_daily.csv')
+    data_file_name = join(module_path, 'data', 'covid_daily.zip')
 
-    df_long = pd.read_csv(data_file_name)
-    df_long['datetime'] = pd.to_datetime(
-        df_long['datetime'], infer_datetime_format=True
-    )
-
-    return df_long
+    df_wide = pd.read_csv(data_file_name, index_col=0, parse_dates=True)
+    if not long:
+        return df_wide
+    else:
+        df_long = df_wide.reset_index(drop=False).melt(
+            id_vars=['datetime'], var_name='series_id', value_name='value'
+        )
+        return df_long
 
 
 def load_fred_monthly():
@@ -43,9 +51,22 @@ def load_fred_monthly():
     return df_long
 
 
-def load_monthly():
+def load_monthly(long: bool = True):
     """Federal Reserve of St. Louis monthly economic indicators."""
-    return load_fred_monthly()
+    if long:
+        return load_fred_monthly()
+    else:
+        from autots.tools.shaping import long_to_wide
+
+        df_long = load_fred_monthly()
+        df_wide = long_to_wide(
+            df_long,
+            date_col='datetime',
+            value_col='value',
+            id_col='series_id',
+            aggfunc='first',
+        )
+        return df_wide
 
 
 def load_fred_yearly():
@@ -68,7 +89,7 @@ def load_fred_yearly():
     monthly_data = get_fred_data(fredkey = 'XXXXXXXXX', SeriesNameDict = SeriesNameDict)
     """
     module_path = dirname(__file__)
-    data_file_name = join(module_path, 'data', 'fred_yearly.csv')
+    data_file_name = join(module_path, 'data', 'fred_yearly.zip')
 
     df_long = pd.read_csv(data_file_name)
     df_long['datetime'] = pd.to_datetime(
@@ -78,12 +99,25 @@ def load_fred_yearly():
     return df_long
 
 
-def load_yearly():
+def load_yearly(long: bool = True):
     """Federal Reserve of St. Louis annual economic indicators."""
-    return load_fred_yearly()
+    if long:
+        return load_fred_yearly()
+    else:
+        from autots.tools.shaping import long_to_wide
+
+        df_long = load_fred_yearly()
+        df_wide = long_to_wide(
+            df_long,
+            date_col='datetime',
+            value_col='value',
+            id_col='series_id',
+            aggfunc='first',
+        )
+        return df_wide
 
 
-def load_traffic_hourly():
+def load_traffic_hourly(long: bool = True):
     """
     From the MN DOT via the UCI data repository.
     Yes, Minnesota is the best state of the Union.
@@ -91,17 +125,23 @@ def load_traffic_hourly():
     module_path = dirname(__file__)
     data_file_name = join(module_path, 'data', 'traffic_hourly.zip')
 
-    df_long = pd.read_csv(data_file_name, compression='zip')
-    df_long['datetime'] = pd.to_datetime(
-        df_long['datetime'], infer_datetime_format=True
+    df_wide = pd.read_csv(
+        data_file_name, index_col=0, parse_dates=True, compression='zip'
     )
+    if not long:
+        return df_wide
+    else:
+        df_long = df_wide.reset_index(drop=False).melt(
+            id_vars=['datetime'], var_name='series_id', value_name='value'
+        )
+        return df_long
 
     return df_long
 
 
-def load_hourly():
+def load_hourly(long: bool = True):
     """Traffic data from the MN DOT via the UCI data repository."""
-    return load_traffic_hourly()
+    return load_traffic_hourly(long=long)
 
 
 def load_eia_weekly():
@@ -116,6 +156,19 @@ def load_eia_weekly():
     return df_long
 
 
-def load_weekly():
+def load_weekly(long: bool = True):
     """Weekly petroleum industry data from the EIA."""
-    return load_eia_weekly()
+    if long:
+        return load_eia_weekly()
+    else:
+        from autots.tools.shaping import long_to_wide
+
+        df_long = load_eia_weekly()
+        df_wide = long_to_wide(
+            df_long,
+            date_col='datetime',
+            value_col='value',
+            id_col='series_id',
+            aggfunc='first',
+        )
+        return df_wide
